==> windmill_api-1.31.0-py3-none-any.whl: windmill_api/models/run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0_type import (
    RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0Type,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0")


@attr.s(auto_attribs=True)
class RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0:
    """ """

    type: RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0Type
    value: Union[Unset, None] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        value = None

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
            }
        )
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0Type(d.pop("type"))

        value = None

        run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0 = cls(
            type=type,
            value=value,
        )

        run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0.additional_properties = d
        return run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.36.0-py3-none-any.whl: windmill_api/models/run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0_type import (
    RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0Type,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0")


@attr.s(auto_attribs=True)
class RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0:
    """
    Attributes:
        type (RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0Type):
        value (Union[Unset, Any]):
    """

    type: RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0Type
    value: Union[Unset, Any] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        value = self.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
            }
        )
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = RunFlowPreviewJsonBodyValueModulesItemValueType2IteratorType0Type(d.pop("type"))

        value = d.pop("value", UNSET)

        run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0 = cls(
            type=type,
            value=value,
        )

        run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0.additional_properties = d
        return run_flow_preview_json_body_value_modules_item_value_type_2_iterator_type_0

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
